aboutsummaryrefslogtreecommitdiff
path: root/eduserver/api/input.go
diff options
context:
space:
mode:
Diffstat (limited to 'eduserver/api/input.go')
-rw-r--r--eduserver/api/input.go42
1 files changed, 41 insertions, 1 deletions
diff --git a/eduserver/api/input.go b/eduserver/api/input.go
index 8b5b6d76..fa7f30cb 100644
--- a/eduserver/api/input.go
+++ b/eduserver/api/input.go
@@ -1,3 +1,7 @@
+// Copyright 2017 Vector Creations Ltd
+// Copyright 2017-2018 New Vector Ltd
+// Copyright 2019-2020 The Matrix.org Foundation C.I.C.
+//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
@@ -37,6 +41,12 @@ type InputTypingEvent struct {
OriginServerTS gomatrixserverlib.Timestamp `json:"origin_server_ts"`
}
+type InputSendToDeviceEvent struct {
+ UserID string `json:"user_id"`
+ DeviceID string `json:"device_id"`
+ gomatrixserverlib.SendToDeviceEvent
+}
+
// InputTypingEventRequest is a request to EDUServerInputAPI
type InputTypingEventRequest struct {
InputTypingEvent InputTypingEvent `json:"input_typing_event"`
@@ -45,6 +55,14 @@ type InputTypingEventRequest struct {
// InputTypingEventResponse is a response to InputTypingEvents
type InputTypingEventResponse struct{}
+// InputSendToDeviceEventRequest is a request to EDUServerInputAPI
+type InputSendToDeviceEventRequest struct {
+ InputSendToDeviceEvent InputSendToDeviceEvent `json:"input_send_to_device_event"`
+}
+
+// InputSendToDeviceEventResponse is a response to InputSendToDeviceEventRequest
+type InputSendToDeviceEventResponse struct{}
+
// EDUServerInputAPI is used to write events to the typing server.
type EDUServerInputAPI interface {
InputTypingEvent(
@@ -52,11 +70,20 @@ type EDUServerInputAPI interface {
request *InputTypingEventRequest,
response *InputTypingEventResponse,
) error
+
+ InputSendToDeviceEvent(
+ ctx context.Context,
+ request *InputSendToDeviceEventRequest,
+ response *InputSendToDeviceEventResponse,
+ ) error
}
// EDUServerInputTypingEventPath is the HTTP path for the InputTypingEvent API.
const EDUServerInputTypingEventPath = "/eduserver/input"
+// EDUServerInputSendToDeviceEventPath is the HTTP path for the InputSendToDeviceEvent API.
+const EDUServerInputSendToDeviceEventPath = "/eduserver/sendToDevice"
+
// NewEDUServerInputAPIHTTP creates a EDUServerInputAPI implemented by talking to a HTTP POST API.
func NewEDUServerInputAPIHTTP(eduServerURL string, httpClient *http.Client) (EDUServerInputAPI, error) {
if httpClient == nil {
@@ -70,7 +97,7 @@ type httpEDUServerInputAPI struct {
httpClient *http.Client
}
// InputRoomEvents implements EDUServerInputAPI
func (h *httpEDUServerInputAPI) InputTypingEvent(
ctx context.Context,
request *InputTypingEventRequest,
@@ -82,3 +109,16 @@ func (h *httpEDUServerInputAPI) InputTypingEvent(
apiURL := h.eduServerURL + EDUServerInputTypingEventPath
return internalHTTP.PostJSON(ctx, span, h.httpClient, apiURL, request, response)
}
+
+// InputSendToDeviceEvent implements EDUServerInputAPI
+func (h *httpEDUServerInputAPI) InputSendToDeviceEvent(
+ ctx context.Context,
+ request *InputSendToDeviceEventRequest,
+ response *InputSendToDeviceEventResponse,
+) error {
+ span, ctx := opentracing.StartSpanFromContext(ctx, "InputSendToDeviceEvent")
+ defer span.Finish()
+
+ apiURL := h.eduServerURL + EDUServerInputSendToDeviceEventPath
+ return internalHTTP.PostJSON(ctx, span, h.httpClient, apiURL, request, response)
+}
@@ -70,7 +97,7 @@ type httpEDUServerInputAPI struct {
httpClient *http.Client
}
-// InputRoomEvents implements EDUServerInputAPI
+// InputTypingEvent implements EDUServerInputAPI
func (h *httpEDUServerInputAPI) InputTypingEvent(
ctx context.Context,